Crate lum_config

Crate lum_config 

Re-exports

pub use env_handler::EnvHandler;
pub use file_handler::FileHandler;
pub use error::*;
pub use merger::*;

Modules

env_handler
Environment-related configuration handling.
error
Error types used across the crate.
file_handler
File-related configuration handling.
merger
Traits and helper functions for merging configurations.

Functions

load
Loads configurations from environment variables and a file, and merges them together. This function is a convenience function that combines the functionality of EnvHandler, FileHandler, and merger.